Flask-Ipernity
===============

Flask-Ipernity is a `Flask`_ extension that offers access to the `Ipernity`_
API via `PyIpernity`_. It can be used to authorize to Ipernity, and together
with `Flask-Login`_ provide user login via Ipernity.

.. warning:: This package is still under development. Use at your own risk.


Installation
-------------

.. code-block:: console
    
    pip install Flask-Ipernity

The source code is available at `<http://github.com/rcw-2/flask-ipernity>`_.


.. _Flask: https://flask.palletsprojects.com/
.. _Ipernity: http://www.ipernity.com/
.. _PyIpernity: https://pyipernity.readthedocs.io/
.. _Flask-Login: https://flask-login.readthedocs.io/

